@@ -69,7 +69,6 @@ class ArenaSelector::Private
         void _k_updatePreview(QListWidgetItem* currentItem = nullptr);
         void _k_updateArenaList(const QString& strArena);
         void _k_openKNewStuffDialog();
-        void _k_importArenasDialog();
         void _k_setRandomArenaMode(bool randomModeEnabled);
         void _k_updateRandomArenaModeArenaList(QListWidgetItem* item);
 };
@@ -154,7 +153,6 @@ void ArenaSelector::Private::setupData(KConfigSkeleton * aconfig)
     //Now get our arenas into the list widget
     findArenas(lastUsedArena);
 
-    connect(ui.importArenas, SIGNAL(clicked()), q, SLOT(_k_importArenasDialog()));
     connect(ui.kcfg_RandomArenaMode, SIGNAL(toggled(bool)), q, SLOT(_k_setRandomArenaMode(bool)));
 }
 
@@ -170,34 +168,26 @@ void ArenaSelector::Private::findArenas(const QString &initialSelection)
 
     QStringList arenasAvailable;
     const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::AppDataLocation, QStringLiteral("arenas"), QStandardPaths::LocateDirectory);
-    Q_FOREACH (const QString& dir, dirs) {
+    for(auto& dir: dirs) {
          const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.desktop"));
-         Q_FOREACH (const QString& file, fileNames) {
+         for(auto& file: fileNames) {
                 arenasAvailable.append(file);
          }
     }
-
-    QStringList::Iterator i = m_tempRandomArenaModeArenaList.begin();
-    while(i != m_tempRandomArenaModeArenaList.end())
-    {
-        if(arenasAvailable.contains(*i))
-        {
-            i++;
-        }
-        else
-        {
-            i = m_tempRandomArenaModeArenaList.erase(i);
+    
+    QStringList randomArenaModeArenaList;
+    // store the random arenas if they are available
+    for(const auto& randomArena: m_tempRandomArenaModeArenaList) {
+        if(arenasAvailable.contains(randomArena)) {
+            randomArenaModeArenaList.append(randomArena);
         }
     }
 
-    if(m_tempRandomArenaModeArenaList.isEmpty())
-    {
-        m_tempRandomArenaModeArenaList = arenasAvailable;
-    }
+    m_tempRandomArenaModeArenaList = randomArenaModeArenaList.isEmpty() ? arenasAvailable : randomArenaModeArenaList;
 
     bool initialFound = false;
 
-    foreach (const QString &file, arenasAvailable)
+    for(const auto& file: arenasAvailable)
     {
       QString arenaPath = lookupDirectory + QLatin1Char('/') + file;
       ArenaSettings* arenaSettings = new ArenaSettings(groupName);
@@ -243,7 +233,7 @@ void ArenaSelector::Private::findArenas(const QString &initialSelection)
     {
       // TODO change this if we ever change ArenaSettings::loadDefault
       QLatin1String defaultPath("arenas/granatier.desktop");
-      foreach(ArenaSettings* arenaSettings, arenaMap)
+      for(auto arenaSettings: arenaMap)
       {
         if (arenaSettings->path().endsWith(defaultPath))
         {
@@ -333,8 +323,8 @@ void ArenaSelector::Private::_k_updatePreview(QListWidgetItem* currentItem)
     }
 
     //calculate the scaling factor for the SVGs
-    int horizontalPixelsPerCell = (ui.arenaPreview->size().width() - 4) / (minSize.width()/Granatier::CellSize);
-    int verticalPixelsPerCell = (ui.arenaPreview->size().height() - 4) / (minSize.height()/Granatier::CellSize);
+    int horizontalPixelsPerCell = static_cast<int>((ui.arenaPreview->size().width() - 4) / (minSize.width()/Granatier::CellSize));
+    int verticalPixelsPerCell = static_cast<int>((ui.arenaPreview->size().height() - 4) / (minSize.height()/Granatier::CellSize));
     if(horizontalPixelsPerCell < verticalPixelsPerCell)
     {
         svgScaleFactor = Granatier::CellSize / horizontalPixelsPerCell;
@@ -354,7 +344,7 @@ void ArenaSelector::Private::_k_updatePreview(QListWidgetItem* currentItem)
         if(m_svgScaleFactor != svgScaleFactor)
         {
             m_svgScaleFactor = svgScaleFactor;
-            foreach(KGameRenderedItem* arenaItem, m_arenaItems)
+            for(auto arenaItem: m_arenaItems)
             {
                 arenaItem->setRenderSize(calculateSvgSize());
                 arenaItem->setScale(m_svgScaleFactor);
@@ -437,7 +427,7 @@ QSize ArenaSelector::Private::calculateSvgSize()
     QPoint topLeft(0, 0);
     topLeft = m_graphicsScene->views().first()->mapFromScene(topLeft);
 
-    QPoint bottomRight(Granatier::CellSize, Granatier::CellSize);
+    QPoint bottomRight(static_cast<int>(Granatier::CellSize), static_cast<int>(Granatier::CellSize));
     bottomRight = m_graphicsScene->views().first()->mapFromScene(bottomRight);
 
     QSize svgSize;
@@ -476,100 +466,6 @@ void ArenaSelector::Private::_k_openKNewStuffDialog()
     delete dialog;
 }
 
-void ArenaSelector::Private::_k_importArenasDialog()
-{
-    // get local directory for arenas
-    const QString arenaDir = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1String("/arenas/");
-    // create path if it does not exist
-    if(!QDir(arenaDir).exists()) QDir().mkpath(arenaDir);
-
-
-    //find the clanbomber files
-    QStringList listClanbomberPaths;
-    listClanbomberPaths.append(QDir::homePath() + QLatin1String("/.clanbomber/maps/"));
-    for(int i = 0; i < listClanbomberPaths.count(); i++)
-    {
-        QDir clanbomberDir(listClanbomberPaths[i]);
-        if(!clanbomberDir.exists())
-        {
-            continue;
-        }
-
-        QStringList listMaps;
-        listMaps = clanbomberDir.entryList(QStringList(QStringLiteral("*.map")));
-        for(int j = 0; j < listMaps.count(); j++)
-        {
-            QFile mapFile(listClanbomberPaths[i] + listMaps[j]);
-            mapFile.open(QIODevice::ReadOnly | QIODevice::Text);
-            QTextStream readStream(&mapFile);
-
-            QString strAuthor = readStream.readLine();
-
-            QFile desktopFile;
-            QString strName = listMaps[j].left(listMaps[j].count()-4);
-            desktopFile.setFileName(QStringLiteral("%1clanbomber_%2.desktop").arg(arenaDir).arg(strName));
-            desktopFile.open(QIODevice::WriteOnly | QIODevice::Text);
-            QTextStream streamDesktopFile(&desktopFile);
-
-            streamDesktopFile << "[Arena]\n";
-            streamDesktopFile << "Name=" << strName << "\n";
-            streamDesktopFile << "Description=Clanbomber Import\n";
-            streamDesktopFile << "Type=XML\n";
-            streamDesktopFile << "FileName=clanbomber_" << strName << ".xml\n";
-            streamDesktopFile << "Author=" << strAuthor << "\n";
-            streamDesktopFile << "AuthorEmail=-\n";
-
-            streamDesktopFile.flush();
-            desktopFile.close();
-
-            QStringList arena;
-            do
-            {
-                arena.append(readStream.readLine());
-            }
-            while(!readStream.atEnd());
-            arena.replaceInStrings(QStringLiteral("*"), QStringLiteral("="));
-            arena.replaceInStrings(QStringLiteral(" "), QStringLiteral("_"));
-            arena.replaceInStrings(QStringLiteral("-"), QStringLiteral(" "));
-            arena.replaceInStrings(QStringLiteral("S"), QStringLiteral("-"));
-            arena.replaceInStrings(QStringLiteral("R"), QStringLiteral("x"));
-            arena.replaceInStrings(QStringLiteral("^"), QStringLiteral("u"));
-            arena.replaceInStrings(QStringLiteral(">"), QStringLiteral("r"));
-            arena.replaceInStrings(QStringLiteral("v"), QStringLiteral("d"));
-            arena.replaceInStrings(QStringLiteral("<"), QStringLiteral("l"));
-            arena.replaceInStrings(QStringLiteral("0"), QStringLiteral("p"));
-            arena.replaceInStrings(QStringLiteral("1"), QStringLiteral("p"));
-            arena.replaceInStrings(QStringLiteral("2"), QStringLiteral("p"));
-            arena.replaceInStrings(QStringLiteral("3"), QStringLiteral("p"));
-            arena.replaceInStrings(QStringLiteral("4"), QStringLiteral("p"));
-            arena.replaceInStrings(QStringLiteral("5"), QStringLiteral("p"));
-            arena.replaceInStrings(QStringLiteral("6"), QStringLiteral("p"));
-            arena.replaceInStrings(QStringLiteral("7"), QStringLiteral("p"));
-            arena.replaceInStrings(QStringLiteral("8"), QStringLiteral("p"));
-            arena.replaceInStrings(QStringLiteral("9"), QStringLiteral("p"));
-            QFile arenaFile;
-            arenaFile.setFileName(QStringLiteral("%1clanbomber_%2.xml").arg(arenaDir).arg(strName));
-            arenaFile.open(QIODevice::WriteOnly | QIODevice::Text);
-
-            QTextStream streamArenaFile(&arenaFile);
-
-            streamArenaFile << "<?xml version=\"1.0\"?>\n";
-            streamArenaFile << "<Arena arenaFileVersion=\"1\" rowCount=\"" << arena.count() << "\" colCount=\"" << arena[0].count() << "\">\n";
-            for(int j = 0; j < arena.count(); j++)
-            {
-                streamArenaFile << "  <Row>" << arena[j] << "</Row>\n";
-            }
-            streamArenaFile << "</Arena>\n";
-
-            streamArenaFile.flush();
-            arenaFile.close();
-        }
-    }
-
-    ArenaSettings* selArena = arenaMap.value(ui.arenaList->currentItem()->text());
-    findArenas(selArena->fileName());
-}
-
 void ArenaSelector::Private::_k_setRandomArenaMode(bool randomModeEnabled)
 {
     if(!randomModeEnabled)
